Get a list of matrices with the log probabilities of possible words given their previous context using a causal transformer
Source:R/defunct.R
causal_lp_mats-defunct.RdThis function is defunct. Use causal_pred_mats() instead.
,
Skip to contents
R/defunct.R
causal_lp_mats-defunct.RdThis function is defunct. Use causal_pred_mats() instead.